middleware

package
v0.0.81 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 19, 2025 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CustomContextMiddleware

func CustomContextMiddleware() gin.HandlerFunc

CustomContextMiddleware adds custom context to all requests

func GinContextFromContext

func GinContextFromContext(ctx context.Context) (*gin.Context, bool)

GinContextFromContext extracts the Gin context from a context

func GinContextToContextMiddleware

func GinContextToContextMiddleware() gin.HandlerFunc

GinContextToContextMiddleware adds the Gin context to the request context

func TenantValidationMiddleware

func TenantValidationMiddleware() gin.HandlerFunc

func TracingMiddleware

func TracingMiddleware(parentCtx context.Context) gin.HandlerFunc

TracingMiddleware creates a new span for each request and adds common tags

func UserIdMiddleware

func UserIdMiddleware() gin.HandlerFunc

Types

This section is empty.

Jump to